import type { Text } from "@codemirror/state";
import type { EditorView } from "@codemirror/view";
import type * as LSP from "vscode-languageserver-protocol";
export declare function posToOffset(doc: Text, pos: {
    line: number;
    character: number;
}): number | undefined;
export declare function posToOffsetOrZero(doc: Text, pos: {
    line: number;
    character: number;
}): number;
export declare function offsetToPos(doc: Text, offset: number): {
    character: number;
    line: number;
};
export declare function formatContents(contents: LSP.MarkupContent | LSP.MarkedString | LSP.MarkedString[] | undefined): string;
/**
 * Analyzes completion items to generate regex patterns for matching prefixes.
 * Used to determine what text should be considered part of the current token
 * when filtering completion items.
 *
 * @param items - Array of LSP completion items to analyze
 * @returns A tuple of two RegExp objects:
 *   1. A pattern that matches from the start of a string
 *   2. A pattern that matches anywhere in a string
 */
export declare function prefixMatch(items: LSP.CompletionItem[]): RegExp[];
export declare function isLSPTextEdit(textEdit?: LSP.TextEdit | LSP.InsertReplaceEdit): textEdit is LSP.TextEdit;
export declare function isLSPMarkupContent(contents: LSP.MarkupContent | LSP.MarkedString | LSP.MarkedString[]): contents is LSP.MarkupContent;
export declare function showErrorMessage(view: EditorView, message: string): void;
export declare function isEmptyDocumentation(documentation: LSP.MarkupContent | LSP.MarkedString | LSP.MarkedString[] | undefined): boolean;
/**
 * Calculates the correct starting position for completion based on token content
 * @param position Current cursor position
 * @param token Optional completion token
 * @returns The adjusted position for completion
 */
export declare function calculateCompletionPosition(position: number, token: {
    from: number;
    text: string;
} | null): number;
//# sourceMappingURL=utils.d.ts.map